@@ -42,6 +42,7 @@
 #include "parole-gst-iface.h"
 
 #include "common/parole-common.h"
+#include "common/parole-rc-utils.h"
 
 #include "gst-enum-types.h"
 #include "gstmarshal.h"
@@ -186,7 +187,6 @@ parole_gst_parent_expose_event (GtkWidget *w, GdkEventExpose *ev, ParoleGst *gst
     return FALSE;
 }
 
-
 static void
 parole_gst_realize (GtkWidget *widget)
 {
@@ -345,7 +345,8 @@ parole_gst_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
 	w = allocation->width;
 	h = allocation->height;
 	
-	parole_gst_get_video_output_size (PAROLE_GST (widget), &w, &h);
+	if ( PAROLE_GST (widget)->priv->embedded == FALSE )
+	    parole_gst_get_video_output_size (PAROLE_GST (widget), &w, &h);
 
 	width = w;
 	height = h;
@@ -519,6 +520,8 @@ parole_gst_expose_event (GtkWidget *widget, GdkEventExpose *ev)
 
     parole_gst_set_x_overlay (gst);
 
+    TRACE ("EXPOSE event state=%d  target=%d", gst->priv->state, gst->priv->target);
+    
     switch ( gst->priv->state )
     {
 	case GST_STATE_PLAYING:
@@ -534,7 +537,7 @@ parole_gst_expose_event (GtkWidget *widget, GdkEventExpose *ev)
 		parole_gst_helper_draw_logo (PAROLE_GST_HELPER (gst));
 	    break;
 	case GST_STATE_READY:
-	    if (gst->priv->with_vis == FALSE && gst->priv->target != GST_STATE_PLAYING)
+	    if (gst->priv->target != GST_STATE_PLAYING)
 		parole_gst_helper_draw_logo (PAROLE_GST_HELPER (gst));
 	    else
 		gst_x_overlay_expose (GST_X_OVERLAY (gst->priv->video_sink));
@@ -783,8 +786,7 @@ parole_gst_get_pad_capabilities (GObject *object, GParamSpec *pspec, ParoleGst *
 			  "disp-par-d", den,
 			  NULL);
 	}
-		      
-	parole_gst_get_video_output_size (gst, &width, &height);
+
 	parole_gst_size_allocate (GTK_WIDGET (gst), &GTK_WIDGET (gst)->allocation);
     }
 }
@@ -1452,7 +1454,6 @@ parole_gst_change_dvd_chapter (ParoleGst *gst, gint level)
 {
     GstFormat format;
 
-    // FIXME: Do we really need to get the nick each time?
     format = gst_format_get_by_nick ("chapter");
     
     parole_gst_seek_by_format (gst, format, level);
@@ -1668,8 +1669,12 @@ parole_gst_constructed (GObject *object)
 {
     ParoleGst *gst;
     
+    gboolean enable_xv;
+    
     gst = PAROLE_GST (object);
     
+    enable_xv = parole_rc_read_entry_bool ("enable-xv", PAROLE_RC_GROUP_GENERAL, TRUE);
+    
     gst->priv->playbin = gst_element_factory_make ("playbin", "player");
  
     if ( G_UNLIKELY (gst->priv->playbin == NULL) )
@@ -1680,12 +1685,16 @@ parole_gst_constructed (GObject *object)
 	g_error ("playbin load failed");
     }
     
-    gst->priv->video_sink = gst_element_factory_make ("xvimagesink", "video");
-    gst->priv->xvimage_sink = TRUE;
+    if (enable_xv)
+    {
+	gst->priv->video_sink = gst_element_factory_make ("xvimagesink", "video");
+	gst->priv->xvimage_sink = TRUE;
+    }
+    
     if ( G_UNLIKELY (gst->priv->video_sink == NULL) )
     {
 	gst->priv->xvimage_sink = FALSE;
-	g_debug ("xvimagesink not found, trying to load ximagesink"); 
+	g_debug ("%s trying to load ximagesink", enable_xv ? "xvimagesink not found " : "xv disabled "); 
 	gst->priv->video_sink = gst_element_factory_make ("ximagesink", "video");
 	
 	if ( G_UNLIKELY (gst->priv->video_sink == NULL) )
@@ -2185,3 +2194,10 @@ parole_gst_set_cursor_visible (ParoleGst *gst, gboolean visible)
     else
 	parole_window_invisible_cursor (GTK_WIDGET (gst)->window);
 }
+
+const ParoleStream     *parole_gst_get_stream 		(ParoleGst *gst)
+{
+    g_return_val_if_fail (PAROLE_IS_GST (gst), NULL);
+    
+    return gst->priv->stream;
+}
