@@ -30,6 +30,7 @@
 #include <X11/XF86keysym.h>
 #endif
 
+#include <gdk/gdkx.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 
@@ -144,6 +145,10 @@ void		parole_player_open_preferences_cb	(GtkWidget *widget,
 void            parole_player_volume_value_changed_cb   (GtkRange *range, 
 							 ParolePlayer *player);
 
+gboolean        parole_player_volume_scroll_event_cb	(GtkWidget *widget,
+							 GdkEventScroll *ev,
+							 ParolePlayer *player);
+
 void		parole_player_full_screen_activated_cb  (GtkWidget *widget,
 							 ParolePlayer *player);
 
@@ -394,7 +399,6 @@ parole_player_media_activated_cb (ParoleMediaList *list, GtkTreeRowReference *ro
 				 parole_file_get_uri (file),
 				 sub);
 	    g_free (sub);
-	    gtk_widget_grab_focus (player->priv->gst);
 	    g_object_unref (file);
 	}
     }
@@ -407,7 +411,6 @@ parole_player_disc_selected_cb (ParoleDisc *disc, const gchar *uri, const gchar
     gtk_widget_set_sensitive (player->priv->stop, TRUE);
     
     parole_gst_play_device_uri (PAROLE_GST (player->priv->gst), uri, device);
-    gtk_widget_grab_focus (player->priv->gst);
 }
 
 static void
@@ -415,7 +418,6 @@ parole_player_uri_opened_cb (ParoleMediaList *list, const gchar *uri, ParolePlay
 {
     parole_player_reset (player);
     gtk_widget_set_sensitive (player->priv->stop, TRUE);
-    gtk_widget_grab_focus (player->priv->gst);
     parole_gst_play_uri (PAROLE_GST (player->priv->gst), uri, NULL);
 }
 
@@ -537,7 +539,11 @@ parole_player_playing (ParolePlayer *player, const ParoleStream *stream)
     gtk_widget_set_sensitive (player->priv->range, seekable);
     
     player->priv->internal_range_change = TRUE;
-    gtk_range_set_range (GTK_RANGE (player->priv->range), 0, live ? 0 : duration);
+    if ( live || duration == 0)
+	parole_player_change_range_value (player, 0);
+    else 
+	gtk_range_set_range (GTK_RANGE (player->priv->range), 0, duration);
+	
     player->priv->internal_range_change = FALSE;
     
     gtk_widget_set_sensitive (player->priv->seekf, seekable);
@@ -548,6 +554,8 @@ parole_player_playing (ParolePlayer *player, const ParoleStream *stream)
 	g_object_unref (pix);
 	
     parole_player_save_uri (player, stream);
+    
+    gtk_widget_grab_focus (player->priv->gst);
 }
 
 static void
@@ -699,21 +707,40 @@ parole_player_play_prev (ParolePlayer *player)
 }
 
 static void
-parole_player_media_state_cb (ParoleGst *gst, const ParoleStream *stream, ParoleMediaState state, ParolePlayer *player)
+parole_player_reset_saver_changed (ParolePlayer *player, const ParoleStream *stream)
 {
-    gboolean has_video;
+    gboolean reset_saver;
     
-    PAROLE_DEBUG_ENUM ("State callback", state, GST_ENUM_TYPE_MEDIA_STATE);
+    TRACE ("Start");
     
-    g_object_get (G_OBJECT (stream),
-		  "has-video", &has_video,
+    g_object_get (G_OBJECT (player->priv->conf),
+		  "reset-saver", &reset_saver,
 		  NULL);
-    
-    if ( state == PAROLE_MEDIA_STATE_PLAYING && has_video )
-	parole_screen_saver_inhibit (player->priv->screen_saver);
+		  
+    if ( !reset_saver )
+	parole_screen_saver_uninhibit (player->priv->screen_saver);
+    else if ( player->priv->state ==  PAROLE_MEDIA_STATE_PLAYING )
+    {
+	gboolean has_video;
+	
+	g_object_get (G_OBJECT (stream),
+		      "has-video", &has_video,
+		      NULL);
+		      
+	if ( has_video )
+	    parole_screen_saver_inhibit (player->priv->screen_saver);
+    }
     else
 	parole_screen_saver_uninhibit (player->priv->screen_saver);
+}
 
+static void
+parole_player_media_state_cb (ParoleGst *gst, const ParoleStream *stream, ParoleMediaState state, ParolePlayer *player)
+{
+    PAROLE_DEBUG_ENUM ("State callback", state, GST_ENUM_TYPE_MEDIA_STATE);
+
+    parole_player_reset_saver_changed (player, stream);
+    
     if ( state == PAROLE_MEDIA_STATE_PLAYING )
     {
 	parole_player_playing (player, stream);
@@ -799,7 +826,7 @@ gboolean parole_player_scroll_event_cb (GtkWidget *widget, GdkEventScroll *ev, P
     }
     else if ( ev->direction == GDK_SCROLL_DOWN )
     {
-	parole_player_seekf_cb (NULL, player);
+	parole_player_seekb_cb (NULL, player);
         ret_val = TRUE;
     }
 
@@ -1291,6 +1318,25 @@ parole_player_change_volume (ParolePlayer *player, gdouble value)
     parole_player_set_volume_image (player, value);
 }
 
+gboolean
+parole_player_volume_scroll_event_cb (GtkWidget *widget, GdkEventScroll *ev, ParolePlayer *player)
+{
+    gboolean ret_val = FALSE;
+
+    if ( ev->direction == GDK_SCROLL_UP )
+    {
+	parole_player_volume_up (NULL, player);
+	ret_val = TRUE;
+    }
+    else if ( ev->direction == GDK_SCROLL_DOWN )
+    {
+	parole_player_volume_down (NULL, player);
+	ret_val = TRUE;
+    }
+
+    return ret_val;
+}
+
 void
 parole_player_volume_value_changed_cb (GtkRange *range, ParolePlayer *player)
 {
@@ -1339,11 +1385,11 @@ parole_player_finalize (GObject *object)
     
     dbus_g_connection_unref (player->priv->bus);
     
+    g_object_unref (player->priv->conf);
     g_object_unref (player->priv->video_filter);
     g_object_unref (player->priv->status);
     g_object_unref (player->priv->disc);
     g_object_unref (player->priv->disc_menu);
-    g_object_unref (player->priv->conf);
     g_object_unref (player->priv->screen_saver);
     
 #ifdef HAVE_XF86_KEYSYM
@@ -1367,6 +1413,22 @@ parole_player_class_init (ParolePlayerClass *klass)
     parole_player_dbus_class_init (klass);
 }
 
+/**
+ * Configuration changed regarding
+ * whether to Reset the screen saver counter
+ * while playing movies or not.
+ * 
+ */
+static void
+parole_player_reset_saver_changed_cb (ParolePlayer *player)
+{
+    const ParoleStream *stream;
+    
+    stream = parole_gst_get_stream (PAROLE_GST (player->priv->gst));
+    TRACE ("Reset saver configuration changed");
+    parole_player_reset_saver_changed (player, stream);
+}
+
 static gboolean
 parole_player_handle_key_press (GdkEventKey *ev, ParolePlayer *player)
 {
@@ -1658,6 +1720,44 @@ parole_player_window_notify_is_active (ParolePlayer *player)
     }
 } 
 
+/**
+ * 
+ * Sets the _NET_WM_WINDOW_OPACITY_LOCKED wm hint 
+ * so window manager keep us opaque.
+ * 
+ * Currently it is only supported by xfwm.
+ * 
+ * NOTE: The widget has to be realized first.
+ **/
+static void
+parole_player_set_wm_opacity_hint (GtkWidget *widget)
+{
+    GdkScreen *gdkscreen;
+    GdkDisplay *gdkdisplay;
+    GdkWindow *gdkwindow;
+    Display *xdisplay;
+    Atom atom;
+    char mode = 1;
+    
+    gdkscreen = gtk_widget_get_screen (widget);
+    gdkdisplay = gdk_screen_get_display (gdkscreen);
+
+    xdisplay = GDK_DISPLAY_XDISPLAY (gdkdisplay);
+    
+    atom = XInternAtom (xdisplay, "_NET_WM_WINDOW_OPACITY_LOCKED", TRUE);
+    
+    if ( atom == None )
+	return;
+    
+    gdkwindow = gtk_widget_get_window (widget);
+    
+    XChangeProperty (xdisplay, GDK_WINDOW_XID (gdkwindow),
+		     atom, XA_CARDINAL,
+		     32, PropModeAppend,
+		     (guchar *) &mode, 
+		     1);
+}
+
 static void
 parole_player_init (ParolePlayer *player)
 {
@@ -1678,6 +1778,10 @@ parole_player_init (ParolePlayer *player)
     builder = parole_builder_get_main_interface ();
     
     player->priv->conf = parole_conf_new ();
+    
+    g_signal_connect_swapped (player->priv->conf, "notify::reset-saver",
+			      G_CALLBACK (parole_player_reset_saver_changed_cb), player);
+    
     player->priv->session = parole_session_get ();
     
     g_signal_connect_swapped (player->priv->session, "die",
@@ -1744,6 +1848,7 @@ parole_player_init (ParolePlayer *player)
 		      G_CALLBACK (parole_player_drag_data_received_cb), player);
     
     player->priv->window = GTK_WIDGET (gtk_builder_get_object (builder, "main-window"));
+   
     player->priv->main_nt = GTK_WIDGET (gtk_builder_get_object (builder, "main-notebook"));
     
     player->priv->play_pause = GTK_WIDGET (gtk_builder_get_object (builder, "play-pause"));
@@ -1785,6 +1890,8 @@ parole_player_init (ParolePlayer *player)
     
     gtk_widget_show_all (player->priv->window);
     
+    parole_player_set_wm_opacity_hint (player->priv->window);
+    
     gtk_box_pack_start (GTK_BOX (output), 
 			player->priv->gst,
 			TRUE, TRUE, 0);
